==============
django-galicia
==============

Country-specific Django helpers for Galicia (Spain), as in django-localflavor.

What is django-galicia?
=========================

For now, it's just a couple of form widgets:

* GaliciaMunicipalitySelect: A ``Select`` widget that uses a list of Galician
  municipalities as its choices.

* GaliciaProvinceSelect: ``A Select`` widget that uses a list of Galician
  provinces as its choices.

* GaliciaComarcaSelect: ``A Select`` widget that uses a list of Galician comarcas
  as its choices.

